@@ -21,11 +21,33 @@
 
 """
 Returns a magma-list containing the file name. Takes the names as input.
+
+# Test strip_dirname
+
+    >>> a = "blah/blubb/bangala/goi.gis"
+    >>> print strip_dirname(a)
+    goi.gis
+    
+    >>> a = "/blah/blubb/bangala/goi.gis"
+    >>> print strip_dirname(a)
+    goi.gis
+    
 """
 # Get the sha1_berechnen module. 
-from magma.sha1_berechnen import sha1_berechnen
+from sha1_berechnen import sha1_berechnen
 # And get the yaml dumper and loader
 from yaml import dump, load
+# And the dirname to be able to strip it. 
+from os.path import dirname
+
+def strip_dirname(path):
+    """Strip everything but the name of the file."""
+    # We just as many characters from the beginning of the string as the dirname is long. 
+    if len(dirname(path)) > 0: 
+        filename = path[len(dirname(path)) + 1:]
+    else: 
+        filename = path
+    return filename
 
 class Magma: 
     def __init__(self, inputfilenames): 
@@ -43,11 +65,15 @@ class Magma:
             magnet = {}
             magnet['hash'] = {}
             magnet['hash']['sha1'] = self.sha1[i]
-            magnet['name'] = i
+            magnet['name'] = strip_dirname(i)
             list_of_magnets.append(magnet)
         magma['files'] = list_of_magnets
         return "#MAGMAv0.4\n" + dump(magma, default_flow_style=False)
 
+def _test(): 
+    from doctest import testmod
+    testmod()
+
 #### Self-Test ####
 if __name__ == '__main__': 
     from sys import argv
@@ -60,3 +86,6 @@ if __name__ == '__main__':
     magma = Magma(filenames)
     print magma.magma
     
+    # And test. 
+    _test()
+    
