@@ -161,7 +161,7 @@ class Magma(object):
         # First get the file handle for the magma file
         file_handle = open(path, "w")
         # Then write the data in yaml format. 
-        file_handle.write(self.get_yaml_data())
+        file_handle.write(self.dump())
         # And close the file handle. 
         file_handle.close()
         
@@ -176,7 +176,7 @@ class Magma(object):
         
     def dump(self):
         """Return the yaml data"""
-        return "MAGMAv0.4\n" + self.get_yaml_data()
+        return "#MAGMAv0.4\n" + self.get_yaml_data()
 
 
 # Also we have files inside the magma list. They hate a few extra attributes to be easier to use than raw dictionaries. 
